@@ -1,5 +1,4 @@
-use crate::functions::{emsg, wsum};
-use crate::{MStats, Med, Stats, Vecf64};
+use crate::{MStats, Med, Stats, Vecf64, functions::wsum, here};
 use anyhow::{ensure, Result};
 
 impl Stats for &[f64] {
@@ -12,7 +11,7 @@ impl Stats for &[f64] {
     /// ```
     fn amean(self) -> Result<f64> {
         let n = self.len();
-        ensure!(n > 0, emsg(file!(), line!(), "amean - sample is empty!"));
+        ensure!(n > 0, "{} sample is empty!",here!());
         Ok(self.iter().sum::<f64>() / (n as f64))
     }
 
@@ -27,7 +26,7 @@ impl Stats for &[f64] {
     /// ```
     fn ameanstd(self) -> Result<MStats> {
         let n = self.len();
-        ensure!(n > 0, emsg(file!(), line!(), "ameanstd - sample is empty!"));
+        ensure!(n > 0, "{} sample is empty!",here!());
         let mut sx2 = 0_f64;
         let mean = self
             .iter()
@@ -54,7 +53,7 @@ impl Stats for &[f64] {
     /// ```
     fn awmean(self) -> Result<f64> {
         let n = self.len();
-        ensure!(n > 0, emsg(file!(), line!(), "awmean - sample is empty!"));
+        ensure!(n > 0, "{} sample is empty!", here!());
         let mut iw = (n + 1) as f64; // descending linear weights
         Ok(self
             .iter()
@@ -79,10 +78,7 @@ impl Stats for &[f64] {
     /// ```
     fn awmeanstd(self) -> Result<MStats> {
         let n = self.len();
-        ensure!(
-            n > 0,
-            emsg(file!(), line!(), "awmeanstd - sample is empty!")
-        );
+        ensure!(n > 0, "{} sample is empty!", here!());        
         let mut sx2 = 0_f64;
         let mut w = n as f64; // descending linear weights
         let mean = self
@@ -110,13 +106,10 @@ impl Stats for &[f64] {
     /// ```
     fn hmean(self) -> Result<f64> {
         let n = self.len();
-        ensure!(n > 0, emsg(file!(), line!(), "hmean - sample is empty!"));
+        ensure!(n > 0, "{} sample is empty!", here!());        
         let mut sum = 0_f64;
         for &x in self {
-            ensure!(
-                x.is_normal(),
-                emsg(file!(), line!(), "hmean does not accept zero valued data!")
-            );
+            ensure!( x.is_normal(),"{} does not accept zero valued data!",here!());         
             sum += 1.0 / x
         }
         Ok(n as f64 / sum)
@@ -132,14 +125,11 @@ impl Stats for &[f64] {
     /// ```
     fn hwmean(self) -> Result<f64> {
         let n = self.len();
-        ensure!(n > 0, emsg(file!(), line!(), "hwmean - sample is empty!"));
+        ensure!(n > 0, "{} sample is empty!", here!());
         let mut sum = 0_f64;
         let mut w = n as f64;
         for &x in self {
-            ensure!(
-                x.is_normal(),
-                emsg(file!(), line!(), "hwmean does not accept zero valued data!")
-            );
+            ensure!(x.is_normal(),"{} does not accept zero valued data!",here!());
             sum += w / x;
             w -= 1_f64;
         }
@@ -159,13 +149,10 @@ impl Stats for &[f64] {
     /// ```
     fn gmean(self) -> Result<f64> {
         let n = self.len();
-        ensure!(n > 0, emsg(file!(), line!(), "gmean - sample is empty!"));
+        ensure!(n > 0, "{} sample is empty!", here!());
         let mut sum = 0_f64;
         for &x in self {
-            ensure!(
-                x.is_normal(),
-                emsg(file!(), line!(), "gmean does not accept zero valued data!")
-            );
+            ensure!( x.is_normal(),"{} does not accept zero valued data!",here!());        
             sum += x.ln()
         }
         Ok((sum / (n as f64)).exp())
@@ -186,14 +173,11 @@ impl Stats for &[f64] {
     /// ```
     fn gwmean(self) -> Result<f64> {
         let n = self.len();
-        ensure!(n > 0, emsg(file!(), line!(), "gwmean - sample is empty!"));
+        ensure!(n > 0, "{} sample is empty!", here!());
         let mut w = n as f64; // descending weights
         let mut sum = 0_f64;
         for &x in self {
-            ensure!(
-                x.is_normal(),
-                emsg(file!(), line!(), "gwmean does not accept zero valued data!")
-            );
+            ensure!(x.is_normal(),"{} does not accept zero valued data!",here!());
             sum += w * x.ln();
             w -= 1_f64;
         }
@@ -213,18 +197,11 @@ impl Stats for &[f64] {
     /// ```
     fn gmeanstd(self) -> Result<MStats> {
         let n = self.len();
-        ensure!(n > 0, emsg(file!(), line!(), "gmeanstd - sample is empty!"));
+        ensure!(n > 0, "{} sample is empty!", here!());
         let mut sum = 0_f64;
         let mut sx2 = 0_f64;
         for &x in self {
-            ensure!(
-                x.is_normal(),
-                emsg(
-                    file!(),
-                    line!(),
-                    "gmeanstd does not accept zero valued data!"
-                )
-            );
+            ensure!(x.is_normal(),"{} does not accept zero valued data!",here!());
             let lx = x.ln();
             sum += lx;
             sx2 += lx * lx
@@ -247,22 +224,12 @@ impl Stats for &[f64] {
     /// ```
     fn gwmeanstd(self) -> Result<MStats> {
         let n = self.len();
-        ensure!(
-            n > 0,
-            emsg(file!(), line!(), "gwmeanstd - sample is empty!")
-        );
+        ensure!(n > 0, "{} sample is empty!", here!()); 
         let mut w = n as f64; // descending weights
         let mut sum = 0_f64;
         let mut sx2 = 0_f64;
         for &x in self {
-            ensure!(
-                x.is_normal(),
-                emsg(
-                    file!(),
-                    line!(),
-                    "gwmeanstd does not accept zero valued data!"
-                )
-            );
+            ensure!(x.is_normal(),"{} does not accept zero valued data!",here!());
             let lnx = x.ln();
             sum += w * lnx;
             sx2 += w * lnx * lnx;
